@@ -1,4 +1,4 @@
-#' Summarizing Multinomial Logistic Unfolding model
+#' Summarizing Multinomial Restricted Unfolding Model
 #' 											   
 #' The function summary.mru gives a summary from an object from mru()
 #'
@@ -20,9 +20,13 @@ summary.mru = function(object,...){
   cat("AIC:", object$AIC, "\n" )
   cat("BIC:", object$BIC, "\n" )
   cat("\n")
-  cat("B coefficients:", "\n")
-  print(round(object$B, digits = 2))
+  cat("Bx coefficients:", "\n")
+  print(round(object$Bx, digits = 2))
   cat("\n")
+  if(!is.null(object$Bz)){
+    cat("Bz coefficients:", "\n")
+    print(round(object$Bz, digits = 2))
+  }
   cat("V coefficients:", "\n")
   print(round(object$V, digits = 2))
   cat("\n")
