@@ -26,10 +26,15 @@
 
 #ifdef iszero
   #undef iszero  // use own iszero
-#endif			   
+#endif
+
+struct measurement_struct { int NUMERICAL; int ORDINAL; int NOMINAL; };
+static const struct measurement_struct MEASUREMENTLEVEL = { .NUMERICAL = 0, .ORDINAL = 1, .NOMINAL = 2 };
+struct transformation_struct { int ABSOLUTE; int RATIO; int LINEAR; int POWER; int BOXCOX; int SPLINE; int ORDINAL; int NOMINAL; };
+static const struct transformation_struct TRANSFORMATIONLEVEL = { .ABSOLUTE = 0, .RATIO = 1, .LINEAR = 2, .POWER = 3, .BOXCOX = 4, .SPLINE = 5, .ORDINAL = 6, .NOMINAL = 7 };
 struct knotstype_struct { int NONE; int USERPROVIDED; int INTERVAL; int PERCENTILE; int MIDPERCENTILE; };
 static const struct knotstype_struct KNOTSTYPE = { .NONE = 0, .USERPROVIDED = 1, .INTERVAL = 2, .PERCENTILE = 3, .MIDPERCENTILE = 4 };
-static const double SYSMIS = -1.0 * DBL_MAX;											
+static const double SYSMIS = -1.0 * DBL_MAX;
 
 extern size_t min_t( const size_t a, const size_t b );
 extern size_t max_t( const size_t a, const size_t b );
@@ -46,11 +51,11 @@ extern bool isnotsysmis( const double a );
 extern double plogis( const double x );
 
 extern void randomize( long *seed );
-extern size_t nextsize_t( void );								 
+extern size_t nextsize_t( void );
 extern double nextdouble( void );
-extern size_t duniform( const size_t n1, const size_t n2 );														   
+extern size_t duniform( const size_t n1, const size_t n2 );
 extern double stdnormal( void );
-extern double stdlognormal( void );							  
+extern double stdlognormal( void );
 extern void permutate_t( const size_t n, size_t* a );
 extern void draw_t( const size_t n, size_t* a, const size_t m, size_t* b, const bool replace );
 extern double choose( double n, double k );
@@ -60,7 +65,6 @@ extern size_t binarysearch( const size_t n, double* x, const double p );
 extern size_t wheel( const size_t n, double* cump, const double r );
 extern void randomZ( const size_t n, const size_t p, double** z, long seed );
 extern double randomDelta( const size_t n, const size_t m, int* vdist, double* vssq, const int edist, const double epr, const long seed, double** delta );
-
 extern double dmin( const size_t n, const double* const a, const size_t inca );
 extern double dmax( const size_t n, const double* const a, const size_t inca );
 extern void dset( const size_t n, const double b, double* const a, const size_t inca );
@@ -69,22 +73,28 @@ extern double dsum( const size_t n, const double* const a, const size_t inca );
 extern double dwsum( const size_t n, const double* const a, const size_t inca, const double* const w, const size_t incw );
 extern void dscal( const size_t n, const double c, double* const a, const size_t inca );
 extern double ddot( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb );
+extern double dwdot( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb, const double* const w, const size_t incw );
 extern double dssq( const size_t n, const double* const a, const size_t inca );
 extern double dwssq( const size_t n, const double* const a, const size_t inca, const double* const w, const size_t incw );
 extern void daxpy( const size_t n, const double c, double* a, const size_t inca, double* b, const size_t incb );
-extern double rmse( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb );
-extern double wrmse( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb, const double* const w, const size_t incw );
+extern double dsse( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb );
+extern double drsse( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb );
+extern double dwsse( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb, const double* const w, const size_t incw );
+extern double drwsse( const size_t n, const double* const a, const size_t inca, const double* const b, const size_t incb, const double* const w, const size_t incw );
 extern void dgemv( const bool transa, const size_t nra, const size_t nca, const double alpha, double** const a, double* const b, const double beta, double* const c );
 extern void dgemm( const bool transa, const bool transb, const size_t nrc, const size_t ncc, const size_t nab, const double alpha, double** const a, double** const b, const double beta, double** const c );
 extern double stddev( const size_t n, const double* const a, const size_t inca );
+extern void doublecenter( const size_t n, double** a );
 extern double fdist1( const size_t p, double* x, double* y );
 extern double fdist( size_t n, double* x, double* y, const size_t inc );
 extern void euclidean1( const size_t n, const size_t p, double** a, double** const r );
 extern void euclidean2( const size_t n, const size_t p, double** a, const size_t m, double** b, double** const r );
 extern void squaredeuclidean1( const size_t n, const size_t p, double** a, double** const r );
 extern void squaredeuclidean2( const size_t n, const size_t p, double** a, const size_t m, double** b, double** const r );
+extern void pdist( const size_t n, double* d, double* w, double* r );
+extern void dsort0( const size_t n, double* const a );
 extern void dsort( const size_t n, double* const a, size_t* const r );
-extern void sort_t( const size_t n, size_t* const a );												  
+extern void sort_t( const size_t n, size_t* const a );
 extern bool symmetric( const size_t n, double** x );
 extern bool anyequal( const size_t n, double* a, const size_t inca, const double c );
 extern bool anynotequal( const size_t n, double* a, const size_t inca, const double c );
@@ -102,7 +112,6 @@ extern double scale( const size_t n, const size_t m, double** a, double** b );
 extern void center( const size_t n, const size_t p, double** z );
 extern double nstress( const size_t n, double** delta, double** d, double** w );
 extern double pearson( const size_t n, double* a, double* b, double* w );
-
 extern bool* getbvector( const size_t nr, const bool c );
 extern void freebvector( bool* a );
 extern int* getivector( const size_t nr, const int c );
@@ -111,29 +120,32 @@ extern size_t* getvector_t( const size_t nr, const size_t c );
 extern void freevector_t( size_t* a );
 extern double* getvector( const size_t nr, const double c );
 extern void freevector( double* a );
-
 extern int** getimatrix( const size_t nr, const size_t nc, const int c );
 extern void freeimatrix( int** a );
 extern size_t** getmatrix_t( const size_t nr, const size_t nc, const size_t c );
 extern void freematrix_t( size_t** a );
+
 extern double** getmatrix( const size_t nr, const size_t nc, const double c );
 extern void freematrix( double** a );
 extern double ***gettensor( const size_t ns, const size_t nr, const size_t nc, const double c );
 extern void freetensor( double*** a );
-
 extern int inverse( const size_t n, double** a );
-extern int mpinverse( const size_t n, const size_t m, double **a, double **inva );																				  
+extern int mpinverse( const size_t n, const size_t m, double **a, double **inva );
 extern int evdcmp( const size_t n, double** vecs, double* vals );
+extern int evdcmp_lanczos( const size_t n, double** a, double** vecs, double* vals, const size_t k );
 extern int svdcmp( const size_t n, const size_t m, double** const a, double** const u, double* w, double** const v );
-																													 																													
 extern int solve( const size_t n, double** a, double* b );
-																													
+
+extern int max_eigen_hessenberg( const size_t n, double** const a, double* mx );
+extern int max_eigen_186( const size_t n, double** const a, double* mx );
+extern int max_eigen_arnoldi( const size_t n, double** const a, const size_t nvecs, double* mx );
 
 extern void nnintercept( const bool symmetric, const size_t n, double** x, double** y, const double mconst, double** w, double** r );
 extern void nnslope( const bool symmetric, const size_t n, double** x, double** y, const double mconst, double** w, double** r );
 extern void nnlinear( const bool symmetric, const size_t n, double** x, double** y, const double mconst, double** w, double** r );
 extern void nnpower( const bool symmetric, const size_t n, double** x, double** y, const double mconst, double** w, const bool use_a, const bool use_b, double** r );
 extern void nnboxcox( const bool symmetric, const size_t n, double** x, double** y, const double mconst, double** w, const bool use_a, const bool use_b, double** r );
+extern void monotone( const size_t n, double* x, double* w );
 extern size_t setindices( const bool symmetric, const size_t n, double** delta, double** w, size_t* index, size_t* ntb, size_t* tbl );
 extern void ordinal1( const bool symmetric, const size_t n, double** d, const double mconst, double** w, const size_t count, size_t* index, const size_t ntb, size_t* tbl, double** gamma );
 extern void ordinal2( const bool symmetric, const size_t n, double** d, const double mconst, double** w, const size_t count, size_t* index, const size_t ntb, size_t* tbl, double** gamma );
@@ -177,8 +189,10 @@ extern void printmatrix( char* title, const size_t n, const size_t m, double** a
 
 extern void echoprogress( const size_t iter, const double fold, const double fhalf, const double fnew );
 
+extern void writematrix( char* name, const size_t n, const size_t m, double** a );
+
 extern double** readmatrix( char* infilename, size_t *n, size_t *m );
-extern char* getdatetime( void );
+extern char* getdatetime(void);
 extern size_t setstarttime( void );
 extern double getelapsedtime( const size_t starttime );
 
@@ -210,4 +224,5 @@ extern void sethashmapint( const size_t mapsize, hashmap* map, char32 key, const
 extern void sethashmapsize_t( const size_t mapsize, hashmap* map, char32 key, const size_t value );
 extern void sethashmapdouble( const size_t mapsize, hashmap* map, char32 key, const double value );
 
+
 #endif
