@@ -8,13 +8,13 @@
 #include "R.h"
 
 extern double mulnomrowresmduneg( const size_t n, const size_t nc, double** g, const size_t m, const size_t px, double** x, double** b, double** v, double** theta, const size_t MAXINNER, const double FCRIT, const size_t MAXITER, const double DCRIT, size_t* lastiter, double* lastdif );
-extern void Cmulnomrowresmduneg( int* rn, int* rnc, double* rg, int* rm, int* rpx, double* rx, double* rb, double* rv, double* rtheta, int* rmaxiter, double* rdcrit, int* rmaxinner, double* rfcrit, double* rdeviance );
+extern void Cmulnomrowresmduneg( int* rn, int* rnc, double* rg, int* rm, int* rpx, double* rx, double* rb, double* rv, double* rtheta, int* rmaxinner, double* rfcrit, int* rmaxiter, double* rdcrit, double* rdeviance );
 
 extern double mulnomcolresmduneg( const size_t n, const size_t nc, double** g, const size_t m, double** u, const size_t pz, double** z, double**c, double** theta, const size_t MAXINNER, const double FCRIT, const size_t MAXITER, const double DCRIT, size_t* lastiter, double* lastdif );
-extern void Cmulnomcolresmduneg( int* rn, int* rnc, double* rg, int* rm, double* ru, int* rpz, double* rz, double* rc, double* rtheta, int* rmaxiter, double* rdcrit, int* rmaxinner, double* rfcrit, double* rdeviance );
+extern void Cmulnomcolresmduneg( int* rn, int* rnc, double* rg, int* rm, double* ru, int* rpz, double* rz, double* rc, double* rtheta, int* rmaxinner, double* rfcrit, int* rmaxiter, double* rdcrit, double* rdeviance );
 
 extern double mulnomresmduneg( const size_t n, const size_t nc, double** g, const size_t m, const size_t px, double** x, double** b, const size_t pz, double** z, double**c, double** theta, const size_t MAXINNER, const double FCRIT, const size_t MAXITER, const double DCRIT, size_t* lastiter, double* lastdif );
-extern void Cmulnomresmduneg( int* rn, int* rnc, double* rg, int* rm, int* rpx, double* rx, double* rb, int* rpz, double* rz, double* rc, double* rtheta, int* rmaxiter, double* rdcrit, int* rmaxinner, double* rfcrit, double* rdeviance );
+extern void Cmulnomresmduneg( int* rn, int* rnc, double* rg, int* rm, int* rpx, double* rx, double* rb, int* rpz, double* rz, double* rc, double* rtheta, int* rmaxinner, double* rfcrit, int* rmaxiter, double* rdcrit, double* rdeviance );
 extern double mulvarbinmduneg( const size_t n, const size_t r, double** y, const size_t m, double** u, double** v, const bool mains, double* mu, const size_t MAXINNER, const double FCRIT, const size_t MAXITER, const double DCRIT, size_t* lastiter, double* lastdif );
 extern void Cmulvarbinmduneg( int* rn, int* rr, double* ry, int* rm, double* ru, double* rv, int* rmains, double* rmu, int* rmaxinner, double* rfcrit, int* rmaxiter, double* rdcrit, double* rdeviance );
 
